from argparse import FileType
from sys import stdin

from django.core.management import BaseCommand

from media.models import Auteur, Vinyle


class Command(BaseCommand):
    def add_arguments(self, parser):
        parser.add_argument('input', nargs='?',
                            type=FileType('r'),
                            default=stdin,
                            help="ISBN to be imported.")

    def handle(self, *args, **options):
        file = options["input"]
        vinyles = []
        for line in file:
            vinyles.append(line[:-1].split('|', 2))

        print("Registering", len(vinyles), "vinyles")

        imported = 0

        for vinyle in vinyles:
            if len(vinyle) != 3:
                continue

            side = vinyle[0]
            title = vinyle[1]
            authors_str = vinyle[2].split('|')
            authors = [Auteur.objects.get_or_create(name=author)[0]
                       for author in authors_str]
            vinyle, created = Vinyle.objects.get_or_create(
                title=title,
                side_identifier=side,
            )
            vinyle.authors.set(authors)
            vinyle.save()

            if not created:
                self.stderr.write(self.style.WARNING(
                    "One vinyle was already imported. Skipping..."))
            else:
                self.stdout.write(self.style.SUCCESS(
                    "Vinyle imported"))
                imported += 1

        self.stdout.write(self.style.SUCCESS(
            "{count} vinyles imported".format(count=imported)))
